/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef COLORRECTANGLE_H_
#define COLORRECTANGLE_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtkmm/drawingarea.h>
#include <glibmm/refptr.h>
#include <gdkmm/color.h>
#include <gdkmm/gc.h>

namespace GtkGUI
{

class ColorRectangle : public Gtk::DrawingArea
{
public:
	ColorRectangle();
	
	ColorRectangle(Gdk::Color const& color);
	
	void setColor(Gdk::Color const& color);
private:
	virtual bool on_expose_event(GdkEventExpose* evt);
	
	Glib::RefPtr<Gdk::GC> m_ptrGC;
	Gdk::Color m_color;
};

} // namespace GtkGUI

#endif
